@@ -32,6 +32,10 @@ class CorsMiddlewareTests(TestCase):
         resp = self.client.get("/")
         assert resp["Vary"] == "Origin"
 
+    def test_get_invalid_origin(self):
+        resp = self.client.get("/", HTTP_ORIGIN="http://example.com]")
+        assert ACCESS_CONTROL_ALLOW_ORIGIN not in resp
+
     @override_settings(CORS_ALLOWED_ORIGINS=["http://example.com"])
     def test_get_not_in_allowed_origins(self):
         resp = self.client.get("/", HTTP_ORIGIN="http://example.org")
@@ -181,7 +185,7 @@ class CorsMiddlewareTests(TestCase):
         django-cors-middleware, so at least this test makes that explicit, especially
         since for the switch to Django 1.10, special-handling will need to be put in
         place to preserve this behaviour. See `ExceptionMiddleware` mention here:
-        https://docs.djangoproject.com/en/3.0/topics/http/middleware/#upgrading-pre-django-1-10-style-middleware  # noqa: B950
+        https://docs.djangoproject.com/en/3.0/topics/http/middleware/#upgrading-pre-django-1-10-style-middleware  # noqa: E501
         """
         resp = self.client.get("/test-401/", HTTP_ORIGIN="http://example.com")
         assert resp.status_code == 401
@@ -333,6 +337,11 @@ class CorsMiddlewareTests(TestCase):
     CORS_REPLACE_HTTPS_REFERER=True, CORS_ALLOWED_ORIGIN_REGEXES=[r".*example.*"]
 )
 class RefererReplacementCorsMiddlewareTests(TestCase):
+    @override_settings(MIDDLEWARE=["corsheaders.middleware.CorsPostCsrfMiddleware"])
+    def test_post_middleware_alone(self):
+        resp = self.client.get("/")
+        assert resp.status_code == 200
+
     def test_get_replaces_referer_when_secure(self):
         resp = self.client.get(
             "/",
